@@ -458,7 +458,7 @@ c      save frscal
 
 
       logical stab_kappa, stab_gamma, stab_cond, stiff_cond, ill_cond
-      logical stab_kappa1, ill_cond_newt, stab_sigma, comparekappa
+      logical stab_kappa1, ill_cond_newt, stab_sigma
       logical errok
 
       parameter (zero = 0.0d+0, one = 1.0d+0)
@@ -530,7 +530,7 @@ c Karline: use precis instead of d1mach
       ddouble = .false.
 
 
-      if (comp_c) then
+*      if (comp_c) then
 *     initialize parameter for the conditioning estimation
       gamma1old  = flmax
       gamma1     = flmax
@@ -544,7 +544,7 @@ c Karline: use precis instead of d1mach
       stiff_cond = .false.
       stab_cond  = .false.
       ill_cond   = .false.
-      endif
+*      endif
 *     initialize parameter for the conditioning estimation
       if (linear) then
          sfatt_alpha = 1e-5
@@ -679,9 +679,9 @@ c       BY BRUGNANO & TRIGIANTE, AND HIGHAM
           ckappa1old = ckappa1
           ckappaold = ckappa
           sigmaold=sigma
-            call CONDESTIM(aleft,aright,nmsh,ncomp,N,xx,topblk,nlbc,
+            call CONDESTIM(aleft,aright,ncomp,N,xx,topblk,nlbc,
      *       ncomp, ajac, ncomp,2*ncomp,ninter,botblk,ncomp-nlbc,
-     *   ipvblk,isign,amg,c1,wrkrhs,ckappa1,gamma1,sigma,ckappa,ckappa2)
+     *   ipvblk,amg,c1,wrkrhs,ckappa1,gamma1,sigma,ckappa,ckappa2)
 
 
            if (iprint .ge. 0) then
@@ -747,9 +747,9 @@ c
            sigmaold=sigma
            N =nmsh*ncomp
            ninter=nmsh-1
-          call CONDESTIM(aleft,aright,nmsh,ncomp,N,xx,topblk,nlbc,
+          call CONDESTIM(aleft,aright,ncomp,N,xx,topblk,nlbc,
      *       ncomp, ajac, ncomp,2*ncomp,ninter,botblk,ncomp-nlbc,
-     *   ipvblk,isign,amg,c1,wrkrhs,ckappa1,gamma1,sigma,ckappa,ckappa2)
+     *   ipvblk,amg,c1,wrkrhs,ckappa1,gamma1,sigma,ckappa,ckappa2)
 
 
 
@@ -808,8 +808,8 @@ C karline: added , after ipar
      *           nmold, xxold, uold, ratdc,
      *           iorder, iflnwt, itnwt, ddouble, maxmsh,
      *           numbig, nummed,wrkrhs,amg,stab_cond,stiff_cond,
-     *           ill_cond_newt,nfail4,
-     *           nfxpnt, fixpnt, irefin,itcond,itcondmax,rpar,ipar,
+     *           nfail4,
+     *           nfxpnt, fixpnt, irefin,itcond,itcondmax,
      *           nmguess,xguess,nygdim,yguess)
 
 
@@ -824,7 +824,7 @@ c       ratdc=dfexmx/defimp , they only use the storage
 
 
 c      if (nodouble .and. .not. forcedouble) then
-c         call selcondmsh(ncomp, nmsh,
+c         call selcondmsh(nmsh,
 c    *     nfxpnt, fixpnt,  nmax, xx,  irefin,
 c    *     nmold, xxold, ddouble, maxmsh,r4,amg)
 c          ddouble = .false.
@@ -856,7 +856,7 @@ c        If(Chstif) Then
            Bigdef=0.0D+0
            Icmph = 1
            Ix = 1
-           Do 405 Iv=1,Nmsh-1
+           Do 406 Iv=1,Nmsh-1
            Do 405 Iu = 1,Ntol
              Ipoint = Ltol(Iu)
              Holdef=Abs(Def8(Ipoint,Iv))
@@ -868,6 +868,7 @@ c        If(Chstif) Then
               intol = Iu
              Endif
  405       Continue
+ 406       Continue
 c   Biggest deferred correction is in component Icmph and
 c   at the mesh interval Ix.
 c   Now compute an explicit deferred correction for this.
@@ -882,18 +883,18 @@ c   Now compute an explicit deferred correction for this.
 
         if (use_c) then
          if ((stiff_cond)) then
-             drat = bigdef/
-     *               (max(one, abs(u(icmph,Ix)))*tol(intol))
+c             drat = bigdef/
+c     *               (max(one, abs(u(icmph,Ix)))*tol(intol))
 
 c            numadd = drat**power
              numadd = 15
-            call smpselcondmsh(ncomp, nmsh,
+            call smpselcondmsh( nmsh,
      *        nfxpnt, fixpnt,  nmax, xx,  irefin,Ix,numadd,
      *        nmold, xxold, ddouble, maxmsh,r4,amg)
               itcond=itcond+1
          else
-             drat = bigdef/
-     *               (max(one, abs(u(icmph,Ix)))*tol(intol))
+c             drat = bigdef/
+c     *               (max(one, abs(u(icmph,Ix)))*tol(intol))
 
 c            numadd = drat**power
              numadd = 15
@@ -901,8 +902,8 @@ c            numadd = drat**power
      *             nmold, xxold, maxmsh)
          endif
        else
-             drat = bigdef/
-     *               (max(one, abs(u(icmph,Ix)))*tol(intol))
+c             drat = bigdef/
+c     *               (max(one, abs(u(icmph,Ix)))*tol(intol))
             numadd = 15
 c            numadd = drat**power
             call smpmsh (nmsh, nmax, xx, Ix, numadd,
@@ -1024,7 +1025,7 @@ c     *             trst6, onto8, reaft6, linear, succes)
      *              rerr, ermx, ratdc,
      *              reaft6, ddouble, succes, maxmsh,
      *              numbig, nummed,
-     *              wrkrhs,amg, stab_cond,ckappa1,gamma1,ckappa,
+     *              wrkrhs,amg, stab_cond,
      *              stiff_cond,itcond, itcondmax)
 
 
@@ -1102,7 +1103,7 @@ c      call dcopy(nmold, xx, 1, xxold, 1)
        endif
 
        if (nodouble .and. .not. forcedouble) then
-          call selcondmsh(ncomp, nmsh,
+          call selcondmsh( nmsh,
      *     nfxpnt, fixpnt,  nmax, xx,  irefin,
      *     nmold, xxold, ddouble, maxmsh,r4,amg)
            ddouble = .false.
@@ -1177,12 +1178,12 @@ c      call dcopy(nmold, xx, 1, xxold, 1)
 
          call conv8( ncomp, nmsh, ntol, ltol, tol,
      *              nfxpnt, fixpnt, linear, nmax,
-     *              xx, nudim, u, def, def6, def8, uold,
+     *              xx, nudim, u,  def6, def8, uold,
      *              ihcomp, irefin, ermx, err6,
      *              etest8, strctr,
      *              ddouble, nmold, xxold, maxmsh, succes, first8,
-     *              wrkrhs,amg, stab_cond,ckappa1,gamma1,ckappa,
-     *              stiff_cond,rpar,ipar,nmguess, xguess,nygdim, yguess)
+     *              wrkrhs,amg, stab_cond,
+     *              stiff_cond,nmguess, xguess,nygdim, yguess)
 
 
 
